//= require <dSS/SystemPanel>
//= require <dSS/util/TimeInfo>

Ext.namespace("dSS", "dSS.config");

dSS.initUI = function() {
	dSS.config.dSSTimeDiff = 0;

    Ext.QuickTips.init();

    Ext.apply(Ext.QuickTips.getQuickTip(), { maxWidth: 500 });

    var params = Ext.urlDecode(window.location.search.substring(1));

    var active = 0;

    var tabs = [
        {
            title: dSS._("Zone", "Zones", 2),
            xtype: 'dsszonebrowser',
            ref: 'zoneBrowser'
        },
        {
            title: dSS._("Scene", "Scenes", 2),
            xtype: 'dssscenespanel',
            ref: 'scenesPanel'
        },
        {
            title: dSS._("Meters"),
            xtype: 'dsmoverviewpanel',
            ref: 'dSMOverviewPanel'
        },
        {
            title: dSS._("System Properties"),
            xtype: 'dsssystempanel',
            ref: 'systemPanel'
        }
    ];

    var viewport = new Ext.Viewport({
        layout: 'border',
        items: [
        {
            xtype: 'box',
            region: 'north',
            height: 70,
            // give north and south regions a height
            autoEl: {
                tag: 'div',
                html: '<a href="http://digitalstrom.org/" alt="' + dSS._("visit digitalSTROM.org") + '"><img id="logo" src="images/ds_logo.png" alt="dS-Logo"></a>' + '<h1><a href="http://digitalstrom.org/" alt="visit digitalSTROM.org">' + dSS._("digitalSTROM Setup") + '</a></h1>' + '<p><span id= \'dssVersion\'>-</span>, <span id=\'dssTime\'>-</span></p>'
            }
        },
        {
            region: 'center',
            xtype: 'tabpanel',
            activeTab: active,
            items: tabs
        }]
    });

    Ext.Ajax.request({
        url: "/json/system/version",
        disableCaching: true,
        success: function(response, options) {
            try {
                var data = Ext.decode(response.responseText);
                if (data.ok === false) {
                    throw new Ext.Error(dSS._("Could not get dSS version"), data.error);
                }
                Ext.get("dssVersion").update(data.result.version);

            } catch(error) {}
        },
        failure: function(response, options) {}
    });

    Ext.Ajax.request({
        url: "/json/system/time",
        disableCaching: true,
        scope: this,
        success: function(response, options) {
            try {
                var data = Ext.decode(response.responseText);
                if (data.ok === false) {
                    throw new Ext.Error(dSS._("Could not get dSS time"), data.error);
                }
                dSS.config.dSSTimeDiff = (Date.now() - (parseInt(data.result.time, 10) * 1000));
                dSS.time.update();

            } catch(error) {}
        },
        failure: function(response, options) {}
    });

    Ext.Ajax.request({
        url: "/json/property/getChildren",
        params: {
            path: "/system/js/settings"
        },
        scope: this,
        method: "GET",
        disableCaching: true,
        success: function(response, options) {
            try {
                var jsonData = Ext.util.JSON.decode(response.responseText);
                if (jsonData.ok) {
                    for (i = 0; i < jsonData.result.length; i++) {
                        /*
                            dSS.config.settings[jsonData.result[i].name] = jsonData.result[i];
                     */
                        getLogFileProperties(jsonData.result[i]);
                    }
                }
            } catch(err) {}
        },
        failure: function(response, options) {
            Ext.MessageBox.alert(dSS._("Error"), dSS._("Could send getChildren command to dSS"));
        }
    });

    function getLogFileProperties(res) {
        Ext.Ajax.request({
            url: "/json/property/getString",
            params: {
                path: "/system/js/settings/" + res.name + "/logfile"
            },
            scope: this,
            method: "GET",
            disableCaching: true,
            success: function(response, options) {
                try {
                    var jsonData = Ext.util.JSON.decode(response.responseText);
                    if (jsonData.ok) {
                        dSS.config.settings[res.name] = {};
                        dSS.config.settings[res.name].logfile = jsonData.result.value;
                    }
                } catch(err) {}
            },
            failure: function(response, options) {
                Ext.MessageBox.alert(dSS._("Error"), dSS._("Could send getChildren command to dSS"));
            }
        });
    }
};

dSS.mainLogin = function()
{

    if (Ext.isIE6 === true) {
        Ext.Msg.alert(dSS._("Error"),
                      dSS._("Internet Explorer 6 is not supported, please " +
                            "upgrade your webbrowser"));
        return;
    }

    Ext.Ajax.request({
        url: '/json/system/login',
        params: {
            user: 'dssadmin',
            password: 'dssadmin'
        },
        scope: this,
        method: "GET",
        disableCaching: true,
        success: function(response, options) {
            try {
                var jsonData = Ext.util.JSON.decode(response.responseText);
                if (jsonData.ok) {
                    dSS.initUI();
                } else {
                    Ext.Msg.alert(dSS._("Error"), 
                                  dSS._("Could not log in") + ': ' +
                                  jsonData.message);
                }
            } catch(err) {
                Ext.Msg.alert(dSS._("Error"), 
                              dSS._("Could not log in") + ': ' + err);

            }
        },
        failure: function(response, options) {
            Ext.Msg.alert(dSS._("Error"), 
                          dSS._("Could not send login command to dSS"));
        }
    });
};

Ext.onReady(function() {
    Ext.get('start').remove();

    Ext.Ajax.request({
        url: dSS.config.langPath,
        scope: this,
        method: "GET",
        disableCaching: true,
        success: function(response, options) {
            try {
                var data = Ext.util.JSON.decode(response.responseText);

                var params = {
                                'domain' : 'dss-installer',
                                'locale_data' : { 'dss-installer' : data }
                             };
                dSS.gt = new Gettext(params);
                dSS.mainLogin();
            } catch(err) {
                Ext.Msg.alert(dSS._("Error"), 
                              dSS._("Could not load language strings") + ': ' +
                              err);
                dSS.mainLogin();

            }
        },
        failure: function(response, options) {
            Ext.Msg.alert(dSS._("Error"), 
                          dSS._("Could not load language strings"));
            dSS.mainLogin();
        }
    });
});

